import os
from pathlib import Path

import coding_games

HEIGHT = 768
WIDTH = 1024
# TITLE = 'Dizzy: Trapped'
# DEFAULT_PATH = Path(os.path.dirname(coding_games.__file__))
# ICON = DEFAULT_PATH / 'images' / 'icon.png'
