<?xml version="1.0" encoding="UTF-8"?>
<tileset version="1.5" tiledversion="1.7.1" name="green_wizard_tileset" tilewidth="32" tileheight="32" tilecount="576" columns="32">
 <image source="../../../../maps/map_images/Screenshot 2021-12-28 at 18.20.00.png" width="1024" height="576"/>
</tileset>
