# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['coding_games',
 'coding_games.examples.games.1. lets_get_moving',
 'coding_games.examples.games.2. moving_things',
 'coding_games.examples.games.4. time_to_move_the_things_to_the_new_level',
 'coding_games.examples.games.5. dizzy_locked',
 'coding_games.examples.games.6. harmfull actor',
 'coding_games.examples.games.7. usable_item',
 'coding_games.items',
 'coding_games.utils']

package_data = \
{'': ['*'],
 'coding_games': ['examples/games/3. Map creation/*',
                  'fonts/*',
                  'images/*',
                  'maps/black_sky.tmx',
                  'maps/black_sky.tmx',
                  'maps/black_sky.tmx',
                  'maps/black_sky.tmx',
                  'maps/black_sky.tmx',
                  'maps/black_sky.tmx',
                  'maps/black_sky.tmx',
                  'maps/black_sky.tmx',
                  'maps/black_sky.tmx',
                  'maps/black_sky.tmx',
                  'maps/black_sky.tmx',
                  'maps/black_sky.tmx',
                  'maps/black_sky.tmx',
                  'maps/black_sky.tmx',
                  'maps/black_sky.tmx',
                  'maps/black_sky.tmx',
                  'maps/black_sky.tmx',
                  'maps/black_sky.tmx',
                  'maps/black_sky.tmx',
                  'maps/black_sky.tmx',
                  'maps/black_sky.tmx',
                  'maps/black_sky.tmx',
                  'maps/black_sky.tmx',
                  'maps/black_sky.tmx',
                  'maps/black_sky.tmx',
                  'maps/black_sky.tmx',
                  'maps/black_sky.tmx',
                  'maps/black_sky.tmx',
                  'maps/black_sky.tmx',
                  'maps/boat_passage.tmx',
                  'maps/boat_passage.tmx',
                  'maps/boat_passage.tmx',
                  'maps/boat_passage.tmx',
                  'maps/boat_passage.tmx',
                  'maps/boat_passage.tmx',
                  'maps/boat_passage.tmx',
                  'maps/boat_passage.tmx',
                  'maps/boat_passage.tmx',
                  'maps/boat_passage.tmx',
                  'maps/boat_passage.tmx',
                  'maps/boat_passage.tmx',
                  'maps/boat_passage.tmx',
                  'maps/boat_passage.tmx',
                  'maps/boat_passage.tmx',
                  'maps/boat_passage.tmx',
                  'maps/boat_passage.tmx',
                  'maps/boat_passage.tmx',
                  'maps/boat_passage.tmx',
                  'maps/boat_passage.tmx',
                  'maps/boat_passage.tmx',
                  'maps/boat_passage.tmx',
                  'maps/boat_passage.tmx',
                  'maps/boat_passage.tmx',
                  'maps/boat_passage.tmx',
                  'maps/boat_passage.tmx',
                  'maps/boat_passage.tmx',
                  'maps/boat_passage.tmx',
                  'maps/boat_passage.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_entry.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_key.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_roof.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/castle_treasure.tmx',
                  'maps/cave.tmx',
                  'maps/cave.tmx',
                  'maps/cave.tmx',
                  'maps/cave.tmx',
                  'maps/cave.tmx',
                  'maps/cave.tmx',
                  'maps/cave.tmx',
                  'maps/cave.tmx',
                  'maps/cave.tmx',
                  'maps/cave.tmx',
                  'maps/cave.tmx',
                  'maps/cave.tmx',
                  'maps/cave.tmx',
                  'maps/cave.tmx',
                  'maps/cave.tmx',
                  'maps/cave.tmx',
                  'maps/cave.tmx',
                  'maps/cave.tmx',
                  'maps/cave.tmx',
                  'maps/cave.tmx',
                  'maps/cave.tmx',
                  'maps/cave.tmx',
                  'maps/cave.tmx',
                  'maps/cave.tmx',
                  'maps/cave.tmx',
                  'maps/cave.tmx',
                  'maps/cave.tmx',
                  'maps/cave.tmx',
                  'maps/cave.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cherry_in_clouds.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/cloud_above_dungeons_entry.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/clouds_to_the_dungeon.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_bedroom.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_dizzy.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_entry.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_green_shield.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_pond.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/dungeon_red_floor.tmx',
                  'maps/empty_map.tmx',
                  'maps/empty_map.tmx',
                  'maps/empty_map.tmx',
                  'maps/empty_map.tmx',
                  'maps/empty_map.tmx',
                  'maps/empty_map.tmx',
                  'maps/empty_map.tmx',
                  'maps/empty_map.tmx',
                  'maps/empty_map.tmx',
                  'maps/empty_map.tmx',
                  'maps/empty_map.tmx',
                  'maps/empty_map.tmx',
                  'maps/empty_map.tmx',
                  'maps/empty_map.tmx',
                  'maps/empty_map.tmx',
                  'maps/empty_map.tmx',
                  'maps/empty_map.tmx',
                  'maps/empty_map.tmx',
                  'maps/empty_map.tmx',
                  'maps/empty_map.tmx',
                  'maps/empty_map.tmx',
                  'maps/empty_map.tmx',
                  'maps/empty_map.tmx',
                  'maps/empty_map.tmx',
                  'maps/empty_map.tmx',
                  'maps/empty_map.tmx',
                  'maps/empty_map.tmx',
                  'maps/empty_map.tmx',
                  'maps/empty_map.tmx',
                  'maps/golden_lion.tmx',
                  'maps/golden_lion.tmx',
                  'maps/golden_lion.tmx',
                  'maps/golden_lion.tmx',
                  'maps/golden_lion.tmx',
                  'maps/golden_lion.tmx',
                  'maps/golden_lion.tmx',
                  'maps/golden_lion.tmx',
                  'maps/golden_lion.tmx',
                  'maps/golden_lion.tmx',
                  'maps/golden_lion.tmx',
                  'maps/golden_lion.tmx',
                  'maps/golden_lion.tmx',
                  'maps/golden_lion.tmx',
                  'maps/golden_lion.tmx',
                  'maps/golden_lion.tmx',
                  'maps/golden_lion.tmx',
                  'maps/golden_lion.tmx',
                  'maps/golden_lion.tmx',
                  'maps/golden_lion.tmx',
                  'maps/golden_lion.tmx',
                  'maps/golden_lion.tmx',
                  'maps/golden_lion.tmx',
                  'maps/golden_lion.tmx',
                  'maps/golden_lion.tmx',
                  'maps/golden_lion.tmx',
                  'maps/golden_lion.tmx',
                  'maps/golden_lion.tmx',
                  'maps/golden_lion.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_goblin.tmx',
                  'maps/green_wizard.tmx',
                  'maps/green_wizard.tmx',
                  'maps/green_wizard.tmx',
                  'maps/green_wizard.tmx',
                  'maps/green_wizard.tmx',
                  'maps/green_wizard.tmx',
                  'maps/green_wizard.tmx',
                  'maps/green_wizard.tmx',
                  'maps/green_wizard.tmx',
                  'maps/green_wizard.tmx',
                  'maps/green_wizard.tmx',
                  'maps/green_wizard.tmx',
                  'maps/green_wizard.tmx',
                  'maps/green_wizard.tmx',
                  'maps/green_wizard.tmx',
                  'maps/green_wizard.tmx',
                  'maps/green_wizard.tmx',
                  'maps/green_wizard.tmx',
                  'maps/green_wizard.tmx',
                  'maps/green_wizard.tmx',
                  'maps/green_wizard.tmx',
                  'maps/green_wizard.tmx',
                  'maps/green_wizard.tmx',
                  'maps/green_wizard.tmx',
                  'maps/green_wizard.tmx',
                  'maps/green_wizard.tmx',
                  'maps/green_wizard.tmx',
                  'maps/green_wizard.tmx',
                  'maps/green_wizard.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/heaven_clouds.tmx',
                  'maps/main_level.tmx',
                  'maps/main_level.tmx',
                  'maps/main_level.tmx',
                  'maps/main_level.tmx',
                  'maps/main_level.tmx',
                  'maps/main_level.tmx',
                  'maps/main_level.tmx',
                  'maps/main_level.tmx',
                  'maps/main_level.tmx',
                  'maps/main_level.tmx',
                  'maps/main_level.tmx',
                  'maps/main_level.tmx',
                  'maps/main_level.tmx',
                  'maps/main_level.tmx',
                  'maps/main_level.tmx',
                  'maps/main_level.tmx',
                  'maps/main_level.tmx',
                  'maps/main_level.tmx',
                  'maps/main_level.tmx',
                  'maps/main_level.tmx',
                  'maps/main_level.tmx',
                  'maps/main_level.tmx',
                  'maps/main_level.tmx',
                  'maps/main_level.tmx',
                  'maps/main_level.tmx',
                  'maps/main_level.tmx',
                  'maps/main_level.tmx',
                  'maps/main_level.tmx',
                  'maps/main_level.tmx',
                  'maps/map_images/*',
                  'maps/pink_bottle.tmx',
                  'maps/pink_bottle.tmx',
                  'maps/pink_bottle.tmx',
                  'maps/pink_bottle.tmx',
                  'maps/pink_bottle.tmx',
                  'maps/pink_bottle.tmx',
                  'maps/pink_bottle.tmx',
                  'maps/pink_bottle.tmx',
                  'maps/pink_bottle.tmx',
                  'maps/pink_bottle.tmx',
                  'maps/pink_bottle.tmx',
                  'maps/pink_bottle.tmx',
                  'maps/pink_bottle.tmx',
                  'maps/pink_bottle.tmx',
                  'maps/pink_bottle.tmx',
                  'maps/pink_bottle.tmx',
                  'maps/pink_bottle.tmx',
                  'maps/pink_bottle.tmx',
                  'maps/pink_bottle.tmx',
                  'maps/pink_bottle.tmx',
                  'maps/pink_bottle.tmx',
                  'maps/pink_bottle.tmx',
                  'maps/pink_bottle.tmx',
                  'maps/pink_bottle.tmx',
                  'maps/pink_bottle.tmx',
                  'maps/pink_bottle.tmx',
                  'maps/pink_bottle.tmx',
                  'maps/pink_bottle.tmx',
                  'maps/pink_bottle.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_mouse.tmx',
                  'maps/pink_statue.tmx',
                  'maps/pink_statue.tmx',
                  'maps/pink_statue.tmx',
                  'maps/pink_statue.tmx',
                  'maps/pink_statue.tmx',
                  'maps/pink_statue.tmx',
                  'maps/pink_statue.tmx',
                  'maps/pink_statue.tmx',
                  'maps/pink_statue.tmx',
                  'maps/pink_statue.tmx',
                  'maps/pink_statue.tmx',
                  'maps/pink_statue.tmx',
                  'maps/pink_statue.tmx',
                  'maps/pink_statue.tmx',
                  'maps/pink_statue.tmx',
                  'maps/pink_statue.tmx',
                  'maps/pink_statue.tmx',
                  'maps/pink_statue.tmx',
                  'maps/pink_statue.tmx',
                  'maps/pink_statue.tmx',
                  'maps/pink_statue.tmx',
                  'maps/pink_statue.tmx',
                  'maps/pink_statue.tmx',
                  'maps/pink_statue.tmx',
                  'maps/pink_statue.tmx',
                  'maps/pink_statue.tmx',
                  'maps/pink_statue.tmx',
                  'maps/pink_statue.tmx',
                  'maps/pink_statue.tmx',
                  'maps/side_walk.tmx',
                  'maps/side_walk.tmx',
                  'maps/side_walk.tmx',
                  'maps/side_walk.tmx',
                  'maps/side_walk.tmx',
                  'maps/side_walk.tmx',
                  'maps/side_walk.tmx',
                  'maps/side_walk.tmx',
                  'maps/side_walk.tmx',
                  'maps/side_walk.tmx',
                  'maps/side_walk.tmx',
                  'maps/side_walk.tmx',
                  'maps/side_walk.tmx',
                  'maps/side_walk.tmx',
                  'maps/side_walk.tmx',
                  'maps/side_walk.tmx',
                  'maps/side_walk.tmx',
                  'maps/side_walk.tmx',
                  'maps/side_walk.tmx',
                  'maps/side_walk.tmx',
                  'maps/side_walk.tmx',
                  'maps/side_walk.tmx',
                  'maps/side_walk.tmx',
                  'maps/side_walk.tmx',
                  'maps/side_walk.tmx',
                  'maps/side_walk.tmx',
                  'maps/side_walk.tmx',
                  'maps/side_walk.tmx',
                  'maps/side_walk.tmx',
                  'maps/upper_stairs.tmx',
                  'maps/upper_stairs.tmx',
                  'maps/upper_stairs.tmx',
                  'maps/upper_stairs.tmx',
                  'maps/upper_stairs.tmx',
                  'maps/upper_stairs.tmx',
                  'maps/upper_stairs.tmx',
                  'maps/upper_stairs.tmx',
                  'maps/upper_stairs.tmx',
                  'maps/upper_stairs.tmx',
                  'maps/upper_stairs.tmx',
                  'maps/upper_stairs.tmx',
                  'maps/upper_stairs.tmx',
                  'maps/upper_stairs.tmx',
                  'maps/upper_stairs.tmx',
                  'maps/upper_stairs.tmx',
                  'maps/upper_stairs.tmx',
                  'maps/upper_stairs.tmx',
                  'maps/upper_stairs.tmx',
                  'maps/upper_stairs.tmx',
                  'maps/upper_stairs.tmx',
                  'maps/upper_stairs.tmx',
                  'maps/upper_stairs.tmx',
                  'maps/upper_stairs.tmx',
                  'maps/upper_stairs.tmx',
                  'maps/upper_stairs.tmx',
                  'maps/upper_stairs.tmx',
                  'maps/upper_stairs.tmx',
                  'maps/upper_stairs.tmx'],
 'coding_games.examples.games.1. lets_get_moving': ['fonts/*',
                                                    'images/*',
                                                    'maps/*'],
 'coding_games.examples.games.2. moving_things': ['fonts/*',
                                                  'images/*',
                                                  'maps/*'],
 'coding_games.examples.games.4. time_to_move_the_things_to_the_new_level': ['fonts/*',
                                                                             'images/*',
                                                                             'maps/*'],
 'coding_games.examples.games.5. dizzy_locked': ['fonts/*',
                                                 'images/*',
                                                 'maps/*'],
 'coding_games.examples.games.6. harmfull actor': ['fonts/*', 'maps/*'],
 'coding_games.examples.games.7. usable_item': ['fonts/*',
                                                'images/*',
                                                'maps/*']}

install_requires = \
['PyTMX>=3.31,<4.0', 'matches>=0.0.1,<0.0.2', 'pgzero>=1.2.1,<2.0.0']

setup_kwargs = {
    'name': 'coding-games',
    'version': '0.1.5',
    'description': 'The library to quickly create 2D games based on the game Dizzy - Prince of Yolkfolk.. The documentation can be found here: https://mirka-filcakova.gitbook.io/dizzy/',
    'long_description': None,
    'author': 'Gabriel Adamcak',
    'author_email': 'adamcakg@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
